/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __DECODE_H__
#define __DECODE_H__

#include <glib.h>
#include "server.h"
#include "group.h"
#include "article.h"
#include "status-item.h"

typedef struct
{
	const Server  * server;
	Group         * group;
	GSList        * articles;
	gboolean        open;
	gchar         * path;
	gchar         * filename;
	StatusItem    * item;
}
decode_data;

void decode_article   (const decode_data   * data);

#endif /* __DECODE_H__ */
